Components › Wizard — Stisla

# Wizard

The wizard is a component to simplify a process with a step-by-step method.

#### Order Status

Order Placed
Payment Completed
Product Shipped
Order Completed
Order Placed
Payment Completed
Product Shipped
Order Canceled
Order Placed
Payment Completed
Product Shipped
Order Pending
Order Placed
Payment Completed
Product Shipped
Order Completed

#### Create New App

User Account
Create an App
Server Information
Name
Email
Address
Role
Developer CEO
I agree with the terms and conditions
Next